<?php
/**
 * @package     Date-To-Age Add-on for JReviews
 * @author      ClickFWD LLC (https://www.jreviews.com)
 * @copyright   Copyright (C) 2010-2019 ClickFWD LLC
 * @license     GNU GPL version 3 or later
 */

defined( 'MVC_FRAMEWORK') or die;

/**
 * The class name matches the file name with the first letter capitalized
 */

class DatetoageComponent extends S2Component {

    var $plugin_order = 0;

    var $name = 'datetoage';

    var $published = false;

    /**
    * Limit plugin to run only in specific controller actions
    */
    var $controllerActions = array(
        'admin_listings'=>'_save',
        'admin_reviews'=>'_save',
        'listings'=>'_save',
        'reviews'=>'_save'
    );

    function startup(&$controller)
    {
        // Alternatively you can run your own checks for controller and actions inside each event

        if(!$this->runPlugin($controller))
        {
            return false;
        }

        $this->published = true;

        // Make the controller properties available in other methods inside this class

        $this->c = &$controller;
    }

    function runPlugin(&$controller)
    {
        // Check if running in desired controller/actions

        if(!isset($this->controllerActions[$controller->name]))
        {
            return false;
        }

        $actions = !is_array($this->controllerActions[$controller->name])
                        ?
                        array($this->controllerActions[$controller->name])
                        :
                        $this->controllerActions[$controller->name];

        if(!in_array('all',$actions) && !in_array($controller->action,$actions))
        {
            return false;
        }

        return true;
    }

    /**
    * Event triggered before the Model::delete method
    * Posted data including the id of the record to be deleted can be found in the $model->data array
    */
    function plgBeforeDelete(&$model, $data) {}

    /**
    * Event triggered after the Model::delete method
    * Posted data including the id of the record to be deleted can be found in the $model->data array
    */
    function plgAfterDelete(&$model, $data) {}

    /**
    * Event triggered before the theme is rendered
    * All variables sent to theme are available via $this->c->viewVars array
    */
    function plgBeforeRender() {}

   /**
     * Event triggered after a Model query is run and before the Model AfterFind event
     * @param  Object $model this is the current model used to store the form data
     * @param  Array $results this is the result array from the query
     * @return Array $results array is returned after being modified
     */
    function plgAfterFind(&$model, $results)
    {
        return $results;
    }

   /**
     * Event triggered after a Model query is run and after the Model AfterFind event
     * @param  Object $model this is the current model used to store the form data
     * @param  Array $results this is the result array from the query
     * @return Array $results array is returned after being modified
     */
    function plgAfterAfterFind(&$model, $results)
    {
        return $results;
    }

    /**
     * Event triggered before the Model data is stored to the database
     * @param  Object $model this is the current model used to store the form data
     * @param  Array $data  includes the form posted data
     * @return Array $data  array is returned after being modified
     */

    function plgBeforeSave(&$model,$data)
    {
        // Grab the add-on configuration values

        $listing_date_field = $this->c->config->get('datetoage-listing-date');

        $listing_age_field = $this->c->config->get('datetoage-listing-age');

        $review_date_field = $this->c->config->get('datetoage-review-date');

        $review_age_field = $this->c->config->get('datetoage-review-age');

        $FieldsArray = Sanitize::getVar($data,'Field');

        // Check if there are any custom fields to process

        if ( empty($FieldsArray) )
        {
            return $data;
        }

        // LISTING logic

        $ListingFields = Sanitize::getVar($FieldsArray,'Listing',array());

        $listing_date = Sanitize::getString($ListingFields,$listing_date_field);

		if ( $model->name == 'Listing' && $listing_date != '' )
        {
            $bday = new DateTime($listing_date);

            $today = new DateTime();

            $diff = $today->diff($bday);

            $data['Field']['Listing'][$listing_age_field] = $diff->y;
        }

        // REVIEW logic

        $ReviewFields = Sanitize::getVar($FieldsArray,'Review',array());

        $review_date = Sanitize::getString($ReviewFields,$review_date_field);

        if($model->name == 'Review' && $review_date != '')
        {
            $bday = new DateTime($review_date);

            $today = new DateTime();

            $diff = $today->diff($bday);

            $data['Field']['Review'][$review_age_field] = $diff->y;
        }

        return $data;
    }

    /**
     * Event triggered after the Model data is stored to the database
     * Posted data can be found in the $model->data array
     * $mode->data['isNew'] is a boolean allow you to run specific actions for new or edited records
     */

    function plgAfterSave(&$model) {}
}